Examples of use
===============

This section presents examples of commands to execute the features of the package.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   examples/vanilla
   examples/customized
   examples/cluster
